document.StringDocument

|  | ## Cheshire3 Object Model: Class StringDocument

Module document :: Class StringDocument

## Class StringDocument
source code

Object Tree:

    baseObjects.Document --+
                           |
                          StringDocument

Instance Methods

__init__(self, text, creator="", history=[], mimeType="", parent=None, filename=None, schema="") The constructer takes the data which should be used to construct the document.
get_raw(self) Return the raw data associated with this document.
find_exception(self, e)

Class Variables

Inherited from `baseObjects.Document`: `documentStore`, `id`, `mimeType`, `parent`, `processHistory`, `text`

Method Details

### __init__(self, text, creator="", history=[], mimeType="", parent=None, filename=None, schema="") (Constructor) | source code
The constructer takes the data which should be used to construct the document. This is implementation dependant. It also optionally may take a creator object, process history information and a mimetype. The parent option is for documents which have been extracted from another document, for example pages from a book. Overrides: baseObjects.Document.__init__ (inherited documentation)

### get_raw(self) | source code
Return the raw data associated with this document. Overrides: baseObjects.Document.get_raw (inherited documentation)

### find_exception(self, e) | source code